==> aws-java-sdk-sts-1.10.50-sources.jar: com/amazonaws/services/securitytoken/model/RegionDisabledException.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.securitytoken.model;

import com.amazonaws.AmazonServiceException;

/**
 * <p>
 * STS is not activated in the requested region for the account that is being
 * asked to create temporary credentials. The account administrator must
 * activate STS in that region using the IAM Console. For more information, see
 * <a href=
 * "http://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html"
 * >Activating and Deactivating AWS STS in an AWS Region</a> in the <i>IAM User
 * Guide</i>.
 * </p>
 */
public class RegionDisabledException extends AmazonServiceException {
    private static final long serialVersionUID = 1L;

    /**
     * Constructs a new RegionDisabledException with the specified error
     * message.
     *
     * @param message
     *        Describes the error encountered.
     */
    public RegionDisabledException(String message) {
        super(message);
    }

}

==> aws-java-sdk-sts-1.10.56-sources.jar: com/amazonaws/services/securitytoken/model/RegionDisabledException.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.securitytoken.model;

import com.amazonaws.AmazonServiceException;

/**
 * <p>
 * STS is not activated in the requested region for the account that is being
 * asked to create temporary credentials. The account administrator must
 * activate STS in that region using the IAM Console. For more information, see
 * <a href=
 * "http://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html"
 * >Activating and Deactivating AWS STS in an AWS Region</a> in the <i>Using
 * IAM</i>.
 * </p>
 */
public class RegionDisabledException extends AmazonServiceException {
    private static final long serialVersionUID = 1L;

    /**
     * Constructs a new RegionDisabledException with the specified error
     * message.
     *
     * @param message
     *        Describes the error encountered.
     */
    public RegionDisabledException(String message) {
        super(message);
    }

}
